summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_posix.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_posix.py')
-rw-r--r--Lib/test/test_posix.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_posix.py b/Lib/test/test_posix.py
index 4ad7350..f4e8aba 100644
--- a/Lib/test/test_posix.py
+++ b/Lib/test/test_posix.py
@@ -824,7 +824,7 @@ class PosixTester(unittest.TestCase):
posix.rename(support.TESTFN + 'ren', support.TESTFN)
raise
else:
- posix.stat(support.TESTFN) # should not throw exception
+ posix.stat(support.TESTFN) # should not raise exception
finally:
posix.close(f)
@@ -842,7 +842,7 @@ class PosixTester(unittest.TestCase):
def test_unlink_dir_fd(self):
f = posix.open(posix.getcwd(), posix.O_RDONLY)
support.create_empty_file(support.TESTFN + 'del')
- posix.stat(support.TESTFN + 'del') # should not throw exception
+ posix.stat(support.TESTFN + 'del') # should not raise exception
try:
posix.unlink(support.TESTFN + 'del', dir_fd=f)
except: